"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeFileContent = exports.test = void 0;
const detect_1 = require("../../../../lib/detect");
const types_1 = require("./types");
const analytics_1 = require("./analytics");
const measurable_methods_1 = require("./measurable-methods");
// this method executes the local processing engine and then formats the results to adapt with the CLI output.
// this flow is the default GA flow for IAC scanning.
async function test(pathToScan, options) {
    try {
        const customRulesPath = options.rules;
        await measurable_methods_1.initLocalCache({ customRulesPath });
        const filesToParse = await measurable_methods_1.loadFiles(pathToScan, options);
        const { parsedFiles, failedFiles } = await measurable_methods_1.parseFiles(filesToParse, options);
        // Duplicate all the files and run them through the custom engine.
        if (customRulesPath) {
            parsedFiles.push(...parsedFiles.map((file) => (Object.assign(Object.assign({}, file), { engineType: types_1.EngineType.Custom }))));
        }
        const scannedFiles = await measurable_methods_1.scanFiles(parsedFiles);
        const iacOrgSettings = await measurable_methods_1.getIacOrgSettings();
        const resultsWithCustomSeverities = await measurable_methods_1.applyCustomSeverities(scannedFiles, iacOrgSettings.customPolicies);
        const formattedResults = measurable_methods_1.formatScanResults(resultsWithCustomSeverities, options, iacOrgSettings.meta);
        analytics_1.addIacAnalytics(formattedResults);
        // TODO: add support for proper typing of old TestResult interface.
        return {
            results: formattedResults,
            // NOTE: No file or parsed file data should leave this function.
            failures: detect_1.isLocalFolder(pathToScan)
                ? failedFiles.map(removeFileContent)
                : undefined,
        };
    }
    finally {
        measurable_methods_1.cleanLocalCache();
    }
}
exports.test = test;
function removeFileContent({ filePath, fileType, failureReason, projectType, }) {
    return {
        filePath,
        fileType,
        failureReason,
        projectType,
    };
}
exports.removeFileContent = removeFileContent;
//# sourceMappingURL=index.js.map